@@ -12,9 +12,9 @@ class FeaturedImage(BaseNode):
                            if k not in special_attrs_map and v.strip()
                            )
         html = f"<picture><img {attrs_s}></picture>"
-        if attrs.get('caption').strip():
+        if attrs.get('caption', '').strip():
             tag = special_attrs_map['caption']
-            html += f"<{tag}> {attrs['caption']} </{tag}>"
+            html += f"<{tag}>{attrs['caption']}</{tag}>"
         return f'<figure class="featured-image">{html}</figure>'
 
 
